==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/FieldRWTagger__241.c <==
// class soot.jimple.toolkits.pointer.FieldRWTagger$1

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class b6d33af8f84fdbc4 soot_G
// @dep_class 6ac5bee50bbabb71 soot_Singletons
// @dep_class 4be7d142345c567b soot_jimple_toolkits_pointer_FieldRWTagger
// @dep_class b826008108c9f948 soot_jimple_toolkits_pointer_FieldRWTagger__241
// @dep_class 6b31ad477c7a55fa soot_jimple_toolkits_pointer_FullObjectSet
// @dep_class 9dbbb271543e0b8f soot_jimple_toolkits_pointer_Union
// @dep_class d2eacdeb35392377 soot_jimple_toolkits_pointer_UnionFactory

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_G
// @dep_header soot_jimple_toolkits_pointer_FieldRWTagger
// @dep_header soot_jimple_toolkits_pointer_FieldRWTagger__241
// @dep_header soot_jimple_toolkits_pointer_FullObjectSet

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/G.h"
#include "soot/jimple/toolkits/pointer/FieldRWTagger.h"
#include "soot/jimple/toolkits/pointer/FieldRWTagger__241.h"
#include "soot/jimple/toolkits/pointer/FullObjectSet.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private final soot.jimple.toolkits.pointer.FieldRWTagger this$0
static _jc_field _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$field_info$this__240 = {
	.name=		"this$0",
	.signature=	"Lsoot/jimple/toolkits/pointer/FieldRWTagger;",
	.class=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type,
	.type=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object, refs[-1].soot_jimple_toolkits_pointer_FieldRWTagger__241.this__240),
};

// Fields
static _jc_field *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$fields[] = {
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$field_info$this__240
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(soot.jimple.toolkits.pointer.FieldRWTagger)
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$linenum_table$_init$47093510616eddf5[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_ptypes$_init$47093510616eddf5[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_types$_init$47093510616eddf5[] = {
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger$type
};

_jc_method _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method_info$_init$47093510616eddf5 = {
	.name=			"<init>",
	.signature=		"(Lsoot/jimple/toolkits/pointer/FieldRWTagger;)V",
	.class=			&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type,
	.param_types=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_types$_init$47093510616eddf5,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_ptypes$_init$47093510616eddf5,
	.signature_hash=	_JC_JLONG(0x47093510616eddf5),
	.access_flags=		0,
	.function=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$_init$47093510616eddf5,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$linenum_table$_init$47093510616eddf5
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_FieldRWTagger__241, _init$47093510616eddf5);

void
_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$_init$47093510616eddf5(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object *this, _jc_soot_jimple_toolkits_pointer_FieldRWTagger$object *param0)
{
	struct _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object *r0;
	struct _jc_soot_jimple_toolkits_pointer_FieldRWTagger$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(72);				// 0
	_JC_REF_FIELD(env, r0, soot_jimple_toolkits_pointer_FieldRWTagger__241, this__240) = r1;
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public soot.jimple.toolkits.pointer.Union newUnion()
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$linenum_table$newUnion$cadc46e7aeca770e[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_ptypes$newUnion$cadc46e7aeca770e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method_info$newUnion$cadc46e7aeca770e = {
	.name=			"newUnion",
	.signature=		"()Lsoot/jimple/toolkits/pointer/Union;",
	.class=			&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type,
	.return_type=		&_jc_soot_jimple_toolkits_pointer_Union$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_ptypes$newUnion$cadc46e7aeca770e,
	.signature_hash=	_JC_JLONG(0xcadc46e7aeca770e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$newUnion$cadc46e7aeca770e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$vtable, soot_jimple_toolkits_pointer_FieldRWTagger__241.newUnion$cadc46e7aeca770e) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$linenum_table$newUnion$cadc46e7aeca770e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_FieldRWTagger__241, newUnion$cadc46e7aeca770e);

_jc_soot_jimple_toolkits_pointer_Union$object *
_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$newUnion$cadc46e7aeca770e(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object *this)
{
	struct _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object *r0;
	struct _jc_soot_jimple_toolkits_pointer_FullObjectSet$object *r2;
	struct _jc_soot_G$object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_ACTIVE_USE(env, soot_jimple_toolkits_pointer_FullObjectSet);
	_JC_ACTIVE_USE(env, soot_G);
	_JC_LINE_NUMBER(72);				// 0
	r3 = _JC_STATIC_FIELD(env, soot_G, instance, 1);
	r2 = _JC_INVOKE_VIRTUAL(env, soot_Singletons, FullObjectSet$fef4fb643aa20464, r3);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$methods[] = {
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method_info$_init$47093510616eddf5,
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method_info$newUnion$cadc46e7aeca770e
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_72[] = {
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_119[] = {
	&_jc_soot_jimple_toolkits_pointer_UnionFactory$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[72]=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_72,
	[113]=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_113,
	[119]=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_119
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/G",	_JC_JLONG(0xb6d33af8f84fdbc4) },
	{ "soot/Singletons",	_JC_JLONG(0x6ac5bee50bbabb71) },
	{ "soot/jimple/toolkits/pointer/FieldRWTagger",	_JC_JLONG(0x4be7d142345c567b) },
	{ "soot/jimple/toolkits/pointer/FullObjectSet",	_JC_JLONG(0x6b31ad477c7a55fa) },
	{ "soot/jimple/toolkits/pointer/Union",	_JC_JLONG(0x9dbbb271543e0b8f) },
	{ "soot/jimple/toolkits/pointer/UnionFactory",	_JC_JLONG(0xd2eacdeb35392377) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$vtype _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type = {
    .type= {
	.name=			"soot/jimple/toolkits/pointer/FieldRWTagger$1",
	.superclass=		&_jc_soot_jimple_toolkits_pointer_UnionFactory$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xb826008108c9f948),
		.source_file=		"FieldRWTagger.java",
		.instance_size=		sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$refs) + sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$fields) / sizeof(*_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$fields),
		.fields=		_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$fields,
		.num_methods=		sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$methods) / sizeof(*_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$methods),
		.methods=		_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$methods,
		.instanceof_hash_table=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$class_depends) / sizeof(*_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$class_depends),
		.class_depends=		_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_toolkits_pointer_UnionFactory= {
	    .newUnion$cadc46e7aeca770e=			// overridden
		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$newUnion$cadc46e7aeca770e,
	},
	.soot_jimple_toolkits_pointer_FieldRWTagger__241= {
	    .newUnion$cadc46e7aeca770e=
		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$newUnion$cadc46e7aeca770e,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/jimple/toolkits/pointer/FieldRWTagger__241.c <==
// class soot.jimple.toolkits.pointer.FieldRWTagger$1

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class b6d33af8f84fdbc4 soot_G
// @dep_class 6ac5bee50bbabb71 soot_Singletons
// @dep_class 4be7d142345c567b soot_jimple_toolkits_pointer_FieldRWTagger
// @dep_class b826008108c9f948 soot_jimple_toolkits_pointer_FieldRWTagger__241
// @dep_class 6b31ad477c7a55fa soot_jimple_toolkits_pointer_FullObjectSet
// @dep_class 9dbbb271543e0b8f soot_jimple_toolkits_pointer_Union
// @dep_class d2eacdeb35392377 soot_jimple_toolkits_pointer_UnionFactory

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_G
// @dep_header soot_jimple_toolkits_pointer_FieldRWTagger
// @dep_header soot_jimple_toolkits_pointer_FieldRWTagger__241
// @dep_header soot_jimple_toolkits_pointer_FullObjectSet

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/G.h"
#include "soot/jimple/toolkits/pointer/FieldRWTagger.h"
#include "soot/jimple/toolkits/pointer/FieldRWTagger__241.h"
#include "soot/jimple/toolkits/pointer/FullObjectSet.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private final soot.jimple.toolkits.pointer.FieldRWTagger this$0
static _jc_field _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$field_info$this__240 = {
	.name=		"this$0",
	.signature=	"Lsoot/jimple/toolkits/pointer/FieldRWTagger;",
	.class=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type,
	.type=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object, refs[-1].soot_jimple_toolkits_pointer_FieldRWTagger__241.this__240),
};

// Fields
static _jc_field *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$fields[] = {
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$field_info$this__240
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(soot.jimple.toolkits.pointer.FieldRWTagger)
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$linenum_table$_init$47093510616eddf5[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_ptypes$_init$47093510616eddf5[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_types$_init$47093510616eddf5[] = {
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger$type
};

_jc_method _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method_info$_init$47093510616eddf5 = {
	.name=			"<init>",
	.signature=		"(Lsoot/jimple/toolkits/pointer/FieldRWTagger;)V",
	.class=			&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type,
	.param_types=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_types$_init$47093510616eddf5,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_ptypes$_init$47093510616eddf5,
	.signature_hash=	_JC_JLONG(0x47093510616eddf5),
	.access_flags=		0,
	.function=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$_init$47093510616eddf5,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$linenum_table$_init$47093510616eddf5
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_FieldRWTagger__241, _init$47093510616eddf5);

void _JC_JCNI_ATTR
_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$_init$47093510616eddf5(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object *this, _jc_soot_jimple_toolkits_pointer_FieldRWTagger$object *param0)
{
	struct _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object *r0;
	struct _jc_soot_jimple_toolkits_pointer_FieldRWTagger$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(72);				// 0
	_JC_REF_FIELD(env, r0, soot_jimple_toolkits_pointer_FieldRWTagger__241, this__240) = r1;
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public soot.jimple.toolkits.pointer.Union newUnion()
//

static _jc_linenum _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$linenum_table$newUnion$cadc46e7aeca770e[];

static const unsigned char _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_ptypes$newUnion$cadc46e7aeca770e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method_info$newUnion$cadc46e7aeca770e = {
	.name=			"newUnion",
	.signature=		"()Lsoot/jimple/toolkits/pointer/Union;",
	.class=			&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type,
	.return_type=		&_jc_soot_jimple_toolkits_pointer_Union$type,
	.param_ptypes=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$param_ptypes$newUnion$cadc46e7aeca770e,
	.signature_hash=	_JC_JLONG(0xcadc46e7aeca770e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$newUnion$cadc46e7aeca770e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$vtable, soot_jimple_toolkits_pointer_FieldRWTagger__241.newUnion$cadc46e7aeca770e) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$linenum_table$newUnion$cadc46e7aeca770e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_toolkits_pointer_FieldRWTagger__241, newUnion$cadc46e7aeca770e);

_jc_soot_jimple_toolkits_pointer_Union$object * _JC_JCNI_ATTR
_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$newUnion$cadc46e7aeca770e(_jc_env *const env, _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object *this)
{
	struct _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object *r0;
	struct _jc_soot_jimple_toolkits_pointer_FullObjectSet$object *r2;
	struct _jc_soot_G$object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_ACTIVE_USE(env, soot_jimple_toolkits_pointer_FullObjectSet);
	_JC_ACTIVE_USE(env, soot_G);
	_JC_LINE_NUMBER(72);				// 0
	r3 = _JC_STATIC_FIELD(env, soot_G, instance, 1);
	r2 = _JC_INVOKE_VIRTUAL(env, soot_Singletons, FullObjectSet$fef4fb643aa20464, r3);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$methods[] = {
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method_info$_init$47093510616eddf5,
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method_info$newUnion$cadc46e7aeca770e
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_72[] = {
	&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_119[] = {
	&_jc_soot_jimple_toolkits_pointer_UnionFactory$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[72]=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_72,
	[101]=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_101,
	[119]=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_bucket_119
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/G",	_JC_JLONG(0xb6d33af8f84fdbc4) },
	{ "soot/Singletons",	_JC_JLONG(0x6ac5bee50bbabb71) },
	{ "soot/jimple/toolkits/pointer/FieldRWTagger",	_JC_JLONG(0x4be7d142345c567b) },
	{ "soot/jimple/toolkits/pointer/FullObjectSet",	_JC_JLONG(0x6b31ad477c7a55fa) },
	{ "soot/jimple/toolkits/pointer/Union",	_JC_JLONG(0x9dbbb271543e0b8f) },
	{ "soot/jimple/toolkits/pointer/UnionFactory",	_JC_JLONG(0xd2eacdeb35392377) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$vtype _jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$type = {
    .type= {
	.name=			"soot/jimple/toolkits/pointer/FieldRWTagger$1",
	.superclass=		&_jc_soot_jimple_toolkits_pointer_UnionFactory$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xb826008108c9f948),
		.source_file=		"FieldRWTagger.java",
		.instance_size=		sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$refs) + sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$fields) / sizeof(*_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$fields),
		.fields=		_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$fields,
		.num_methods=		sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$methods) / sizeof(*_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$methods),
		.methods=		_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$methods,
		.instanceof_hash_table=	_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$class_depends) / sizeof(*_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$class_depends),
		.class_depends=		_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_toolkits_pointer_UnionFactory= {
	    .newUnion$cadc46e7aeca770e=			// overridden
		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$newUnion$cadc46e7aeca770e,
	},
	.soot_jimple_toolkits_pointer_FieldRWTagger__241= {
	    .newUnion$cadc46e7aeca770e=
		&_jc_soot_jimple_toolkits_pointer_FieldRWTagger__241$method$newUnion$cadc46e7aeca770e,
	},
    }
};
